:root{
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
  --wp-editor-canvas-background:#ddd;
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 160.5;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.commands-command-menu{
  border-radius:4px;
  margin:auto;
  max-width:400px;
  position:relative;
  top:calc(5% + 64px);
  width:calc(100% - 32px);
}
@media (min-width:600px){
  .commands-command-menu{
    top:calc(10% + 64px);
  }
}
.commands-command-menu .components-modal__content{
  margin:0;
  padding:0;
}

.commands-command-menu__overlay{
  align-items:start;
  display:block;
}

.commands-command-menu__header{
  align-items:center;
  display:flex;
  padding:0 16px;
}
.commands-command-menu__header .components-button{
  border:1px solid #949494;
  border-radius:2px 0 0 2px;
  border-right:0;
  height:56px;
  justify-content:center;
  width:56px;
}
.commands-command-menu__header .components-button+[cmdk-input]{
  border-bottom-left-radius:0;
  border-top-left-radius:0;
}

.commands-command-menu__header-search-icon:dir(ltr){
  transform:scaleX(-1);
}

.commands-command-menu__container{
  will-change:transform;
}
.commands-command-menu__container [cmdk-input]{
  border:none;
  border-radius:0;
  color:#1e1e1e;
  font-size:15px;
  line-height:28px;
  margin:0;
  outline:none;
  padding:16px 4px;
  width:100%;
}
.commands-command-menu__container [cmdk-input]::placeholder{
  color:#757575;
}
.commands-command-menu__container [cmdk-input]:focus{
  box-shadow:none;
  outline:none;
}
.commands-command-menu__container [cmdk-item]{
  align-items:center;
  border-radius:2px;
  color:#1e1e1e;
  cursor:pointer;
  display:flex;
  font-size:13px;
}
.commands-command-menu__container [cmdk-item]:active,.commands-command-menu__container [cmdk-item][aria-selected=true]{
  background:var(--wp-admin-theme-color);
  color:#fff;
}
.commands-command-menu__container [cmdk-item]:active svg,.commands-command-menu__container [cmdk-item][aria-selected=true] svg{
  fill:#fff;
}
.commands-command-menu__container [cmdk-item][aria-disabled=true]{
  color:#949494;
  cursor:not-allowed;
}
.commands-command-menu__container [cmdk-item] svg{
  fill:#1e1e1e;
}
.commands-command-menu__container [cmdk-item]>div{
  min-height:40px;
  padding:4px 4px 4px 40px;
}
.commands-command-menu__container [cmdk-item]>.has-icon{
  padding-left:8px;
}
.commands-command-menu__container [cmdk-root]>[cmdk-list]{
  max-height:368px;
  overflow:auto;
}
.commands-command-menu__container [cmdk-root]>[cmdk-list] [cmdk-list-sizer]>[cmdk-group]:last-child [cmdk-group-items]:not(:empty){
  padding-bottom:8px;
}
.commands-command-menu__container [cmdk-root]>[cmdk-list] [cmdk-list-sizer]>[cmdk-group]>[cmdk-group-items]:not(:empty){
  padding:0 8px;
}
.commands-command-menu__container [cmdk-empty]{
  align-items:center;
  color:#1e1e1e;
  display:flex;
  justify-content:center;
  padding:8px 0 32px;
  white-space:pre-wrap;
}
.commands-command-menu__container [cmdk-loading]{
  padding:16px;
}
.commands-command-menu__container [cmdk-list-sizer]{
  position:relative;
}

.commands-command-menu__item span{
  display:inline-block;
  overflow:hidden;
  text-overflow:ellipsis;
  white-space:nowrap;
}

.commands-command-menu__item mark{
  background:unset;
  color:inherit;
  font-weight:600;
}

body.admin-color-light{
  --wp-admin-theme-color:#0085ba;
  --wp-admin-theme-color--rgb:0, 133, 186;
  --wp-admin-theme-color-darker-10:#0073a1;
  --wp-admin-theme-color-darker-10--rgb:0, 114.7661290323, 160.5;
  --wp-admin-theme-color-darker-20:#006187;
  --wp-admin-theme-color-darker-20--rgb:0, 96.5322580645, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-light{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-modern{
  --wp-admin-theme-color:#3858e9;
  --wp-admin-theme-color--rgb:56, 88, 233;
  --wp-admin-theme-color-darker-10:#2145e6;
  --wp-admin-theme-color-darker-10--rgb:33.0384615385, 68.7307692308, 230.4615384615;
  --wp-admin-theme-color-darker-20:#183ad6;
  --wp-admin-theme-color-darker-20--rgb:23.6923076923, 58.1538461538, 214.3076923077;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-modern{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-blue{
  --wp-admin-theme-color:#096484;
  --wp-admin-theme-color--rgb:9, 100, 132;
  --wp-admin-theme-color-darker-10:#07526c;
  --wp-admin-theme-color-darker-10--rgb:7.3723404255, 81.914893617, 108.1276595745;
  --wp-admin-theme-color-darker-20:#064054;
  --wp-admin-theme-color-darker-20--rgb:5.7446808511, 63.829787234, 84.2553191489;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-blue{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-coffee{
  --wp-admin-theme-color:#46403c;
  --wp-admin-theme-color--rgb:70, 64, 60;
  --wp-admin-theme-color-darker-10:#383330;
  --wp-admin-theme-color-darker-10--rgb:56.2692307692, 51.4461538462, 48.2307692308;
  --wp-admin-theme-color-darker-20:#2b2724;
  --wp-admin-theme-color-darker-20--rgb:42.5384615385, 38.8923076923, 36.4615384615;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-coffee{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ectoplasm{
  --wp-admin-theme-color:#523f6d;
  --wp-admin-theme-color--rgb:82, 63, 109;
  --wp-admin-theme-color-darker-10:#46365d;
  --wp-admin-theme-color-darker-10--rgb:69.8430232558, 53.6598837209, 92.8401162791;
  --wp-admin-theme-color-darker-20:#3a2c4d;
  --wp-admin-theme-color-darker-20--rgb:57.6860465116, 44.3197674419, 76.6802325581;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ectoplasm{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-midnight{
  --wp-admin-theme-color:#e14d43;
  --wp-admin-theme-color--rgb:225, 77, 67;
  --wp-admin-theme-color-darker-10:#dd382d;
  --wp-admin-theme-color-darker-10--rgb:221.4908256881, 56.1788990826, 45.0091743119;
  --wp-admin-theme-color-darker-20:#d02c21;
  --wp-admin-theme-color-darker-20--rgb:207.8348623853, 44.2201834862, 33.1651376147;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-midnight{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ocean{
  --wp-admin-theme-color:#627c83;
  --wp-admin-theme-color--rgb:98, 124, 131;
  --wp-admin-theme-color-darker-10:#576e74;
  --wp-admin-theme-color-darker-10--rgb:87.0873362445, 110.192139738, 116.4126637555;
  --wp-admin-theme-color-darker-20:#4c6066;
  --wp-admin-theme-color-darker-20--rgb:76.1746724891, 96.384279476, 101.8253275109;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ocean{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-sunrise{
  --wp-admin-theme-color:#dd823b;
  --wp-admin-theme-color--rgb:221, 130, 59;
  --wp-admin-theme-color-darker-10:#d97426;
  --wp-admin-theme-color-darker-10--rgb:216.8782608696, 116.1847826087, 37.6217391304;
  --wp-admin-theme-color-darker-20:#c36922;
  --wp-admin-theme-color-darker-20--rgb:195.147826087, 104.5434782609, 33.852173913;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-sunrise{
    --wp-admin-border-width-focus:1.5px;
  }
}